#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const commander_1 = require("commander");
const ink_1 = require("ink");
const cosmiconfig_1 = require("cosmiconfig");
const path_1 = tslib_1.__importDefault(require("path"));
const p_queue_1 = tslib_1.__importDefault(require("p-queue"));
const App_1 = require("./App");
const Error_1 = require("./Error");
const network_1 = require("./network");
const gitlab_1 = require("./gitlab");
const config_1 = require("./config");
function exit() {
    process.exitCode = 1;
}
const program = (0, commander_1.createCommand)('gitlab-pipeline-deleter');
program
    .storeOptionsAsProperties(false)
    .description('Deletes old GitLab pipelines')
    .arguments('[gitlab-url]')
    .arguments('[project-id]')
    .arguments('[access-token]')
    .option('-d --days <days>', 'older than days', '30')
    .option('--trace', 'show stack traces for errors when possible', false)
    .action(async (gitlabUrlArgument, projectIdArgument, accessTokenArgument, options) => {
    const cliArguments = {
        gitlabUrl: gitlabUrlArgument,
        projectId: projectIdArgument,
        accessToken: accessTokenArgument,
        days: typeof options.days === 'string' ? parseInt(options.days, 10) : 30,
        trace: options.trace === true,
    };
    const configPath = path_1.default.resolve(process.cwd(), 'glpd.config.js');
    const explorer = (0, cosmiconfig_1.cosmiconfig)('gitlab-pipeline-deleter');
    const loadedConfig = await (0, config_1.loadConfig)(configPath, explorer);
    const glpdArguments = loadedConfig.andThen((config) => {
        return (0, config_1.mergeCliArgumentsWithConfig)(cliArguments, config);
    });
    if (glpdArguments.isErr()) {
        (0, ink_1.render)(react_1.default.createElement(Error_1.Error, { exit: exit }, "Missing or invalid arguments"));
        return;
    }
    const { gitlabUrl, projectIds, accessToken, days, trace } = glpdArguments.value;
    const startDate = new Date();
    const listPipelinesFunction = (0, gitlab_1.listPipelines)({
        getRequest: network_1.getRequest,
        gitlabUrl: gitlabUrl,
        accessToken: accessToken,
    });
    const deletePipelineFunction = (0, gitlab_1.deletePipeline)({
        deleteRequest: network_1.deleteRequest,
        gitlabUrl: gitlabUrl,
        accessToken: accessToken,
    });
    const deleteQueue = new p_queue_1.default({ autoStart: false, interval: 1000, intervalCap: 10 });
    (0, ink_1.render)(react_1.default.createElement(App_1.App, { gitlabUrl: gitlabUrl, projectIds: projectIds, accessToken: accessToken, days: days, startDate: startDate, exit: exit, listPipelines: listPipelinesFunction, filterPipelinesByDate: gitlab_1.filterPipelinesByDate, deletePipeline: deletePipelineFunction, deleteQueue: deleteQueue, showStackTraces: trace }));
});
function crash(error) {
    console.error(error);
    exit();
}
program.parseAsync(process.argv).catch(crash);
//# sourceMappingURL=bin.js.map